@@ -284,3 +284,90 @@ capplet_init (int                      argc,
 }
 
 #endif
+
+
+/**
+ * capplet_error_dialog :
+ *
+ * @parent :
+ * @msg : already translated.
+ * @err :
+ *
+ */
+void
+capplet_error_dialog (GtkWindow *parent, char const *msg, GError *err)
+{
+	if (err != NULL) {
+		GtkWidget *dialog;
+
+		dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
+			GTK_DIALOG_DESTROY_WITH_PARENT,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_CLOSE,
+			msg, err->message);
+
+		g_signal_connect (G_OBJECT (dialog),
+			"response",
+			G_CALLBACK (gtk_widget_destroy), NULL);
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
+		g_error_free (err);
+	}
+}
+
+/**
+ * capplet_help :
+ * @parent :
+ * @helpfile :
+ * @section  :
+ *
+ * A quick utility routine to display help for capplets, and handle errors in a
+ * Havoc happy way.
+ **/
+void
+capplet_help (GtkWindow *parent, char const *helpfile, char const *section)
+{
+	GError *error = NULL;
+
+	g_return_if_fail (helpfile != NULL);
+	g_return_if_fail (section != NULL);
+
+	gnome_help_display_desktop (NULL,
+		"user-guide",
+		helpfile, section, &error);
+	if (error != NULL)
+		capplet_error_dialog (parent, 
+			_("There was an error displaying help: %s"),
+			error);
+}
+
+/**
+ * capplet_set_icon :
+ * @window :
+ * @file_name  :
+ *
+ * A quick utility routine to avoid the cut-n-paste of bogus code
+ * that caused several bugs.
+ **/
+void
+capplet_set_icon (GtkWidget *window, char const *icon_file_name)
+{
+	char *path;
+	GdkPixbuf *icon_pixbuf;
+
+	path = g_strconcat (GNOMECC_DATA_DIR "/icons/", icon_file_name, NULL);
+	icon_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+	g_free (path);
+	if (icon_pixbuf == NULL) {
+		path = gnome_pixmap_file (icon_file_name);
+		if (path != NULL) {
+			icon_pixbuf = gdk_pixbuf_new_from_file (path, NULL);
+			g_free (path);
+		}
+	}
+
+	if (icon_pixbuf != NULL) {
+		gtk_window_set_icon (GTK_WINDOW (window), icon_pixbuf);
+		g_object_unref (icon_pixbuf);
+	}
+}
